@@ -26,7 +26,6 @@
 #include <gioerror.h>
 #include <gfile.h>
 
-#include "gioalias.h"
 
 /**
  * SECTION:gappinfo
@@ -466,7 +465,7 @@ g_app_info_get_icon (GAppInfo *appinfo)
  * about the details of the launcher (like what screen it is on).
  * On error, @error will be set accordingly.
  *
- * To lauch the application without arguments pass a %NULL @files list.
+ * To launch the application without arguments pass a %NULL @files list.
  *
  * Note that even if the launch is successful the application launched
  * can fail to start if it runs into problems during startup. There is
@@ -818,7 +817,3 @@ g_app_launch_context_launch_failed (GAppLaunchContext *context,
   if (class->launch_failed != NULL)
     class->launch_failed (context, startup_notify_id);
 }
-
-
-#define __G_APP_INFO_C__
-#include "gioaliasdef.c"
